︠501cf493-6b28-4e95-9c36-6f32265363bas︠
def rowvacuation_ideal(P,I):
    r = P.rank()
    f = P.rank_function()
    my_order_ideal = I
    for i in range(r+1):
        for j in range(r+1-i):
            s = r+1-j-1
            for x in P:
                if f(x)==s:
                    my_order_ideal = P.order_ideal_toggle(my_order_ideal,x)
    return my_order_ideal

def antichain_from_ideal(P,I):
    return P.subposet(set(P).difference(set(I))).minimal_elements()

def antichain_size(P,I):
    return len(antichain_from_ideal(P,I))

def antichain_toggle(P,A,x):
    if x in A:
        return list(set(A).difference(set([x])))
    else:
        flag=true
        for y in A:
            if (P.le(x,y) or P.le(y,x)):
                flag=false
        if flag:
            return list(set(A).union(set([x])))
        else:
            return A

def rowvacuation_antichain(P,A):
    r = P.rank()
    f = P.rank_function()
    my_antichain = A
    for i in range(r+1):
        for j in range(i,r+1):
            for x in P:
                if f(x)==j:
                    my_antichain = antichain_toggle(P,my_antichain,x)
    return my_antichain

def root_poset_rvac_anti_size_test(R):
    n=R.root_lattice().rank()
    print("Root system: " + str(R))
    P = R.root_poset()
    error=[]
    max_error = 0
    num_errors = 0
    totcount=0
    for A in P.antichains_iterator():
        totcount=totcount+1
        B = rowvacuation_antichain(P,A)
        m = len(A)+len(B)
        if not(m==n):
            if abs(m-n) >= max_error:
                error += [(m,A,B)]
                max_error=abs(m-n)
            num_errors = num_errors + 1
    print("Number of antichains of root poset: " + str(totcount))
    print("Number of antichains for which #A + #Rvac(A) != rank: " + str(num_errors))
    if (num_errors > 0):
          print("An example of a failure: " + str(error[0]))

def root_poset_rvac_anti_size_test_oi(R):
    n=R.root_lattice().rank()
    print("Root system: " + str(R))
    P = R.root_poset()
    Q = P.order_ideals_lattice(facade=true)
    error=[]
    num_errors = 0
    totcount=0
    for I in Q:
        totcount=totcount+1
        J = rowvacuation_ideal(P,I)
        m = antichain_size(P,I)+antichain_size(P,J)
        if not(m==n):
            if (num_errors == 0):
                error += [(m,I,J)]
            num_errors = num_errors + 1
    print("Number of antichains of root poset: " + str(totcount))
    print("Number of antichains for which #A + #Rvac(A) != rank: " + str(num_errors))
    if (num_errors > 0):
          print("An example of a failure: " + str(error[0]))

def root_poset_rvac_fix_test(R):
    print("Root system: " + str(R))
    P = R.root_poset()
    count1=0
    count2=0
    totcount=0
    for A in P.antichains_iterator():
        totcount=totcount+1
        B = rowvacuation_antichain(P,A)
        C = rowvacuation_antichain(P,P.order_ideal_complement_generators(A))
        if set(A) == set(B):
            count1 = count1+1
        if set(A) == set(C):
            count2 = count2+1
    print("Number of antichains of root poset: " + str(totcount))
    print("Number fixed by Rvac: " + str(count1))
    print("Number fixed by Row^{-1}*Rvac: " + str(count2))

def root_poset_rvac_fix_test_oi(R):
    print("Root system: " + str(R))
    P = R.root_poset()
    Q = P.order_ideals_lattice(facade=true)
    count1=0
    count2=0
    totcount=0
    for I in Q:
        totcount=totcount+1
        J = rowvacuation_ideal(P,I)
        K = rowvacuation_ideal(P,P.rowmotion(I))
        if I == J:
            count1 = count1+1
        if I == K:
            count2 = count2+1
    print("Number of antichains of root poset: " + str(totcount))
    print("Number fixed by Rvac: " + str(count1))
    print("Number fixed by Row^{-1}*Rvac: " + str(count2))

def noncrossing_refl_fix_test(R):
    W=R.root_lattice().weyl_group()
    print("Weyl group: " + str(W))
    Cmin = W.prod([W.simple_reflection(i) for i in W.coxeter_diagram().bipartite_sets()[0]])
    Cplu = W.prod([W.simple_reflection(i) for i in W.coxeter_diagram().bipartite_sets()[1]])
    C = Cmin*Cplu
    P = list(W.absolute_order_ideal(gens=C))
    print("Number of noncrossing partitions: " + str(len(P)))
    count1 = 0
    count2 = 0
    for x in P:
        y = Cmin*x.inverse()*Cmin.inverse()
        z = C*y.inverse()
        if x==y:
            count1=count1+1
        if x==z:
            count2=count2+1
    print("Number fixed by Refl: " + str(count1))
    print("Number fixed by Krew*Refl: " + str(count2))
︡03e45cf4-f37d-44e7-9e29-b38d53ddfaed︡{"done":true}
︠d5950b1c-c803-473f-888b-3382f5e3cab0s︠
for n in range(2,9):
    R = RootSystem(['A',n])
    root_poset_rvac_anti_size_test(R)
    print()
    root_poset_rvac_fix_test(R)
    #noncrossing_refl_fix_test(R)
    print()
︡a33ee944-fa90-4022-af81-4fb7f697c99e︡{"stdout":"Root system: Root system of type ['A', 2]\nNumber of antichains of root poset: 5\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 2]\nNumber of antichains of root poset: 5\nNumber fixed by Rvac: 1\nNumber fixed by Row^{-1}*Rvac: 3\n\nRoot system: Root system of type ['A', 3]\nNumber of antichains of root poset: 14\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 3]\nNumber of antichains of root poset: 14\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 6\n\nRoot system: Root system of type ['A', 4]\nNumber of antichains of root poset: 42\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 4]\nNumber of antichains of root poset: 42\nNumber fixed by Rvac: 2\nNumber fixed by Row^{-1}*Rvac: 10\n\nRoot system: Root system of type ['A', 5]\nNumber of antichains of root poset: 132"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 5]\nNumber of antichains of root poset: 132"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 20\n\nRoot system: Root system of type ['A', 6]\nNumber of antichains of root poset: 429"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 6]\nNumber of antichains of root poset: 429"}︡{"stdout":"\nNumber fixed by Rvac: 5\nNumber fixed by Row^{-1}*Rvac: 35\n\nRoot system: Root system of type ['A', 7]\nNumber of antichains of root poset: 1430"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 7]\nNumber of antichains of root poset: 1430"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 70\n\nRoot system: Root system of type ['A', 8]\nNumber of antichains of root poset: 4862"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['A', 8]\nNumber of antichains of root poset: 4862"}︡{"stdout":"\nNumber fixed by Rvac: 14\nNumber fixed by Row^{-1}*Rvac: 126\n\n"}︡{"done":true}
︠085a6843-f075-48f1-bf0c-6c3dba6fe8bes︠
for n in range(2,9):
    R = RootSystem(['B',n])
    root_poset_rvac_anti_size_test(R)
    print()
    root_poset_rvac_fix_test(R)
    #noncrossing_refl_fix_test(R)
    print()
︡bd290d38-6185-499c-af25-3524ec8d4fbc︡{"stdout":"Root system: Root system of type ['B', 2]\nNumber of antichains of root poset: 6\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 2]\nNumber of antichains of root poset: 6\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 4\n\nRoot system: Root system of type ['B', 3]\nNumber of antichains of root poset: 20\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 3]\nNumber of antichains of root poset: 20\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 8\n\nRoot system: Root system of type ['B', 4]\nNumber of antichains of root poset: 70\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 4]\nNumber of antichains of root poset: 70"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 16\n\nRoot system: Root system of type ['B', 5]\nNumber of antichains of root poset: 252"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 5]\nNumber of antichains of root poset: 252"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 32\n\nRoot system: Root system of type ['B', 6]\nNumber of antichains of root poset: 924"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 6]\nNumber of antichains of root poset: 924"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 64\n\nRoot system: Root system of type ['B', 7]\nNumber of antichains of root poset: 3432"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 7]\nNumber of antichains of root poset: 3432"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 128\n\nRoot system: Root system of type ['B', 8]\nNumber of antichains of root poset: 12870"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['B', 8]\nNumber of antichains of root poset: 12870"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 256\n\n"}︡{"done":true}
︠ec7c3119-ac85-4e8b-86d7-431f9f63eeecs︠
for n in range(3,9):
    R = RootSystem(['D',n])
    root_poset_rvac_anti_size_test(R)
    print()
    root_poset_rvac_fix_test(R)
    #noncrossing_refl_fix_test(R)
    print()
︡8995388b-aff8-4200-962d-85d0512b48e3︡{"stdout":"Root system: Root system of type ['D', 3]\nNumber of antichains of root poset: 14\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['D', 3]\nNumber of antichains of root poset: 14\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 6\n\nRoot system: Root system of type ['D', 4]\nNumber of antichains of root poset: 50\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['D', 4]\nNumber of antichains of root poset: 50\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 16\n\nRoot system: Root system of type ['D', 5]\nNumber of antichains of root poset: 182"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['D', 5]\nNumber of antichains of root poset: 182"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 26\n\nRoot system: Root system of type ['D', 6]\nNumber of antichains of root poset: 672"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['D', 6]\nNumber of antichains of root poset: 672"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 64\n\nRoot system: Root system of type ['D', 7]\nNumber of antichains of root poset: 2508"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['D', 7]\nNumber of antichains of root poset: 2508"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 108\n\nRoot system: Root system of type ['D', 8]\nNumber of antichains of root poset: 9438"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n\nRoot system: Root system of type ['D', 8]\nNumber of antichains of root poset: 9438"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 256\n\n"}︡{"done":true}
︠6c564d5b-93e6-4f44-8bd2-704cf1beb3ebs︠
R = RootSystem(['G',2])
root_poset_rvac_anti_size_test(R)
print()
root_poset_rvac_fix_test(R)
#noncrossing_refl_fix_test(R)
print()
︡6aa05292-eb54-4877-898b-ca78e5c851e3︡{"stdout":"Root system: Root system of type ['G', 2]\nNumber of antichains of root poset: 8\nNumber of antichains for which #A + #Rvac(A) != rank: 0\n"}︡{"stdout":"\n"}︡{"stdout":"Root system: Root system of type ['G', 2]\nNumber of antichains of root poset: 8\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 4\n"}︡{"stdout":"\n"}︡{"done":true}
︠47476fe1-ee92-4547-8aac-eeaf26ad4f19s︠
R = RootSystem(['F',4])
root_poset_rvac_anti_size_test(R)
print()
root_poset_rvac_fix_test(R)
#noncrossing_refl_fix_test(R)
print()
︡97d92901-57f7-44f0-b8b0-ab2aa85ffbee︡{"stdout":"Root system: Root system of type ['F', 4]\nNumber of antichains of root poset: 105"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 8\nAn example of a failure: (3, [alpha[1] + 2*alpha[2] + 2*alpha[3] + 2*alpha[4]], [alpha[2] + 2*alpha[3] + alpha[4], alpha[1] + alpha[2] + alpha[3]])\n"}︡{"stdout":"\n"}︡{"stdout":"Root system: Root system of type ['F', 4]\nNumber of antichains of root poset: 105"}︡{"stdout":"\nNumber fixed by Rvac: 1\nNumber fixed by Row^{-1}*Rvac: 17\n"}︡{"stdout":"\n"}︡{"done":true}
︠3ae5ba0d-9027-4d79-ad08-cfa5a976cc43s︠
R = RootSystem(['E',6])
root_poset_rvac_anti_size_test(R)
print()
root_poset_rvac_fix_test(R)
#noncrossing_refl_fix_test(R)
print()
︡0058388e-a818-4a5b-a7b5-f39466eeede4︡{"stdout":"Root system: Root system of type ['E', 6]\nNumber of antichains of root poset: 833"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 24\nAn example of a failure: (5, [alpha[1] + alpha[2] + alpha[3] + 2*alpha[4] + alpha[5] + alpha[6]], [alpha[1] + alpha[3] + alpha[4] + alpha[5], alpha[2] + alpha[4] + alpha[5], alpha[2] + alpha[3] + alpha[4], alpha[3] + alpha[4] + alpha[5] + alpha[6]])\n"}︡{"stdout":"\n"}︡{"stdout":"Root system: Root system of type ['E', 6]\nNumber of antichains of root poset: 833"}︡{"stdout":"\nNumber fixed by Rvac: 5\nNumber fixed by Row^{-1}*Rvac: 47\n"}︡{"stdout":"\n"}︡{"done":true}
︠8c879fbb-b686-42c1-bed7-7a7e9a34a15cs︠
R = RootSystem(['E',7])
root_poset_rvac_anti_size_test(R)
print()
root_poset_rvac_fix_test(R)
#noncrossing_refl_fix_test(R)
print()
︡82be8505-6454-4b10-b2ef-10404e28d11f︡{"stdout":"Root system: Root system of type ['E', 7]\nNumber of antichains of root poset: 4160"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 354\nAn example of a failure: (9, [alpha[2] + alpha[3] + 2*alpha[4] + 2*alpha[5] + alpha[6], alpha[2] + alpha[4] + alpha[5] + alpha[6] + alpha[7], alpha[1] + alpha[2] + 2*alpha[3] + 2*alpha[4] + alpha[5], alpha[1] + alpha[2] + alpha[3] + alpha[4] + alpha[5] + alpha[6], alpha[1] + alpha[3] + alpha[4] + alpha[5] + alpha[6] + alpha[7]], [alpha[2] + alpha[3] + 2*alpha[4] + alpha[5] + alpha[6], alpha[2] + alpha[3] + alpha[4] + alpha[5] + alpha[6] + alpha[7], alpha[1] + alpha[3] + alpha[4] + alpha[5] + alpha[6] + alpha[7], alpha[1] + alpha[2] + 2*alpha[3] + 2*alpha[4] + alpha[5]])\n"}︡{"stdout":"\n"}︡{"stdout":"Root system: Root system of type ['E', 7]\nNumber of antichains of root poset: 4160"}︡{"stdout":"\nNumber fixed by Rvac: 0\nNumber fixed by Row^{-1}*Rvac: 132\n"}︡{"stdout":"\n"}︡{"done":true}
︠448bdede-5c30-43e7-aa83-db0a804924d4s︠
R = RootSystem(['E',8])
root_poset_rvac_anti_size_test(R)
print()
root_poset_rvac_fix_test(R)
##noncrossing_refl_fix_test(R)
print()
︡a1903517-e9a9-42a3-be7f-a2f49f44ca40︡{"stdout":"Root system: Root system of type ['E', 8]\nNumber of antichains of root poset: 25080"}︡{"stdout":"\nNumber of antichains for which #A + #Rvac(A) != rank: 4582\nAn example of a failure: (10, [2*alpha[1] + 2*alpha[2] + 3*alpha[3] + 4*alpha[4] + 3*alpha[5] + 2*alpha[6] + alpha[7], alpha[1] + alpha[2] + alpha[3] + 2*alpha[4] + 2*alpha[5] + 2*alpha[6] + 2*alpha[7] + alpha[8], alpha[1] + alpha[2] + 2*alpha[3] + 3*alpha[4] + 3*alpha[5] + 2*alpha[6] + alpha[7] + alpha[8], alpha[1] + 2*alpha[2] + 2*alpha[3] + 3*alpha[4] + 2*alpha[5] + alpha[6] + alpha[7] + alpha[8]], [alpha[2] + alpha[4] + alpha[5] + alpha[6] + alpha[7] + alpha[8], alpha[1] + alpha[2] + alpha[3] + 2*alpha[4] + alpha[5] + alpha[6], alpha[1] + alpha[3] + alpha[4] + alpha[5] + alpha[6] + alpha[7] + alpha[8], alpha[2] + alpha[3] + 2*alpha[4] + 2*alpha[5] + alpha[6], alpha[2] + alpha[3] + 2*alpha[4] + alpha[5] + alpha[6] + alpha[7], alpha[1] + alpha[2] + alpha[3] + alpha[4] + alpha[5] + alpha[6] + alpha[7]])\n"}︡{"stdout":"\n"}︡{"stdout":"Root system: Root system of type ['E', 8]\nNumber of antichains of root poset: 25080"}︡{"stdout":"\nNumber fixed by Rvac: 14\nNumber fixed by Row^{-1}*Rvac: 278\n"}︡{"stdout":"\n"}︡{"done":true}
︠900c93da-8fa0-4fa4-a5bd-8df6fec346eas︠
def h3_poset():
    return Poset({1:[4],2:[4,5],3:[5],4:[6,7],5:[7],6:[8,9],7:[9],8:[10],9:[10,11],10:[12],11:[12],12:[13],13:[14],14:[15]})

P = h3_poset()
n = 3
error=[]
num_errors = 0
totcount=0
for A in P.antichains_iterator():
    totcount=totcount+1
    B = rowvacuation_antichain(P,A)
    m = len(A)+len(B)
    if not(m==n):
        if (num_errors == 0):
            error += [(m,A,B)]
        num_errors = num_errors + 1
print("Number of antichains of root poset: " + str(totcount))
print("Number of antichains for which #A + #Rvac(A) != rank: " + str(num_errors))
if (num_errors > 0):
    print("An example of a failure: " + str(error[0]))

count1=0
count2=0
totcount=0
for A in P.antichains_iterator():
    totcount=totcount+1
    B = rowvacuation_antichain(P,A)
    C = rowvacuation_antichain(P,P.order_ideal_complement_generators(A))
    if set(A) == set(B):
        count1 = count1+1
    if set(A) == set(C):
        count2 = count2+1
print("Number of antichains of root poset: " + str(totcount))
print("Number fixed by Rvac: " + str(count1))
print("Number fixed by Row^{-1}*Rvac: " + str(count2))

W=CoxeterGroup(['H',3])
print("Weyl group: " + str(W))
Cmin = W.prod([W.simple_reflection(i) for i in W.coxeter_diagram().bipartite_sets()[0]])
Cplu = W.prod([W.simple_reflection(i) for i in W.coxeter_diagram().bipartite_sets()[1]])
C = Cmin*Cplu
P = list(W.absolute_order_ideal(gens=C))
print("Number of noncrossing partitions: " + str(len(P)))
count1 = 0
count2 = 0
for x in P:
    y = Cmin*x.inverse()*Cmin.inverse()
    z = C*y.inverse()
    if x==y:
        count1=count1+1
    if x==z:
        count2=count2+1
print("Number fixed by Refl: " + str(count1))
print("Number fixed by Krew*Refl: " + str(count2))
︡d550916f-6002-4891-9afa-3fba3275f788︡{"stdout":"Number of antichains of root poset: 32\n"}︡{"stdout":"Number of antichains for which #A + #Rvac(A) != rank: 0\n"}︡{"stdout":"Number of antichains of root poset: 32\n"}︡{"stdout":"Number fixed by Rvac: 0\n"}︡{"stdout":"Number fixed by Row^{-1}*Rvac: 8\n"}︡{"stdout":"Weyl group: Finite Coxeter group over Number Field in a with defining polynomial x^2 - 5 with a = 2.236067977499790? with Coxeter matrix:\n[1 3 2]\n[3 1 5]\n[2 5 1]\n"}︡{"stdout":"Number of noncrossing partitions: 32\n"}︡{"stdout":"Number fixed by Refl: 8\n"}︡{"stdout":"Number fixed by Krew*Refl: 0\n"}︡{"done":true}












